@@ -77,6 +77,7 @@ char *OFFOUT_C = "red";
 
 char *EXTERNAL_CHECK = "/usr/lib/xbattbar/xbattbar-check-apm";
 char *EXTERNAL_CHECK_ACPI = "/usr/lib/xbattbar/xbattbar-check-acpi";
+char *EXTERNAL_CHECK_SYS = "/usr/lib/xbattbar/xbattbar-check-sys";
 
 int alwaysontop = False;
 
@@ -238,12 +239,16 @@ main(int argc, char **argv)
   int ch;
 
   about_this_program();
-  while ((ch = getopt(argc, argv, "at:f:hI:i:O:o:p:vs:c")) != -1)
+  while ((ch = getopt(argc, argv, "at:f:hI:i:O:o:p:vs:cr")) != -1)
     switch (ch) {
     case 'c':
       EXTERNAL_CHECK = EXTERNAL_CHECK_ACPI;
       break;
 
+    case 'r':
+      EXTERNAL_CHECK = EXTERNAL_CHECK_SYS;
+      break;
+
     case 's':
       EXTERNAL_CHECK = optarg;
       break;
